# Generated by Django 4.2.3 on 2023-07-11 13:55

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_langchain", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="documentchunk",
            name="index",
            field=models.IntegerField(),
        ),
    ]
